# IMP03 - Version Control

Git workflows, branching strategies, commit conventions.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Git Workflow](IMP03-BP01-Git-Workflow.md) | Branching strategies và git flow |
| BP02 | [Commit Conventions](IMP03-BP02-Commit-Conventions.md) | Quy ước viết commit message |

## Tham khảo

- Atlassian Git Tutorials
- Conventional Commits
- Git Flow by Vincent Driessen
